This is the mail archive of the
fortran@gcc.gnu.org
mailing list for the GNU Fortran project.
Re: Polyhedron performance regression
- From: Tobias Burnus <burnus at net-b dot de>
- To: Dominique Dhumieres <dominiq at lps dot ens dot fr>
- Cc: fortran at gcc dot gnu dot org
- Date: Sun, 19 Nov 2006 23:59:13 +0100
- Subject: Re: Polyhedron performance regression
- References: <20061119222934.34C635BB8B@mailhost.lps.ens.fr>
Hi,
Dominique Dhumieres wrote:
> Sorry to be late, the regression is worse on OSX:
> from ~40s to ~145s. May I also ping this post:
> http://gcc.gnu.org/ml/fortran/2006-07/msg00095.html
>
There is actually a two-step regression on x86_64:
http://www.suse.de/~gcctest/c++bench/polyhedron/polyhedron-summary.txt-2-0.html
Till end of October ~18.6s, since November 5 ~31s and since November 14
~33.5s.
For x86_64 we know the reason: mod is calculated by a library call which
is slow.
See http://gcc.gnu.org/bugzilla/show_bug.cgi?id=29852.
I could imagine that on a PowerPC (?, or do you have an "Intel Mac"?)
you have the analogous problem.
By the way: Has someone an idea what is causing the second regression step?
Tobias